# openpra/inverse-canopy



## Getting Started

Download links:

SSH clone URL: ssh://git@git.space.openpra.org:2222/openpra/inverse-canopy.git

HTTPS clone URL: https://git.space.openpra.org/openpra/inverse-canopy.git



These instructions will get you a copy of the project up and running on your local machine for development and testing purposes.

## Prerequisites

What things you need to install the software and how to install them.

```
Examples
```

## Upload to PyPI

- `python setup.py sdist bdist_wheel`
- `pip install twine`
- `twine upload dist/*`